-- AddOn: SteadyPurse
-- By @poxxerom US megaserver
--
-- Description: This addon keeps your gold purse at a certain (configurable) level of gold, and puts everything else in your bank. 
-- Example: You can configure it for 800g (default). Every time you visit a bank, the addon will deposit enough gold to keep 800g in your purse.
-- If you don't have 800g in your purse, the addon will withdraw gold from your bank to replenish your purse to 800g.
-- Mainly written to prevent myself accidentally sending 15000g instead of ticking "Cash on delivery" <- lesson learnt!
--
-- Update 1.0: Original release
-- Update 1.1: Enabled characters specific settings, added possibility to turn off functionality per character - Thanks Dakhran !
-- Update 1.2: Changed to match API version 100004 which came out with patch 1.1.2
-- Update 1.3: Removed readme.txt from zip file

SteadyPurse = {}
local SPversion = "1.2"
local SP = SteadyPurse
local LAM = LibStub("LibAddonMenu-1.0")
local defaults = {AutoBank = true, KeepInPurse = 800}

local function Initialize(eventCode, addOnName)
	if (addOnName ~= "SteadyPurse") then
		return
	end
	sv = ZO_SavedVars:New("SteadyPurse_SavedVariables", 1, nil, defaults)
	CreateOptions()
	EVENT_MANAGER:RegisterForEvent("SteadyPurse", EVENT_OPEN_BANK, Deposit);
end

function CreateOptions()
	local optionsPanel = LAM:CreateControlPanel('SteadyPurse_Options', '|c3A92FFSteady|cFFD700Purse')
	LAM:AddHeader(optionsPanel, "SteadyPurse_Options_Use_Default", "Deposit Parameters")
	LAM:AddCheckbox(optionsPanel, "ctl_Toggle_AutoBank", "Enable |c3A92FFSteady|cFFD700Purse|cFFFFFF for this char:",
		"Set 'On' to enable automatic deposits and withdrawals",
		function() return sv.AutoBank end,
		function(toggle) sv.AutoBank = toggle end)
	LAM:AddEditBox(optionsPanel, "ctl_Max_KeepInPurse", "Amount to keep in purse:",
		"How much gold you want to keep in your purse", false,
		function () return sv.KeepInPurse end,
		function(keepinpurse) sv.KeepInPurse = tonumber(keepinpurse) end)
end

function Deposit ()
	local currentMoney = GetCurrentMoney()
	local currentBankMoney = GetBankedMoney() 
	
	if (sv.AutoBank == false) then
		return
	end
	
	-- If we have more money than configured to keep in purse, we want to deposit gold in the bank
	if ((currentMoney >= 10) and (currentMoney > sv.KeepInPurse)) then
		local depositAmount = (currentMoney - sv.KeepInPurse)
		DepositMoneyIntoBank(depositAmount)
		d(string.format("SteadyPurse: %d deposited", depositAmount))
	end
	
	-- If we have less money than configured to keep in purse, we want to withdraw gold from the bank
	if (currentMoney < sv.KeepInPurse) then
		if (currentBankMoney >= (sv.KeepInPurse - currentMoney)) then
			local withdrawAmount = (sv.KeepInPurse - currentMoney)
			WithdrawMoneyFromBank(withdrawAmount)
			d(string.format("SteadyPurse: %d withdrawn", withdrawAmount ))
		else
			WithdrawMoneyFromBank(currentBankMoney)
			d(string.format("SteadyPurse: Not enough gold in bank"))
			d(string.format("SteadyPurse: %d withdrawn", currentBankMoney ))
		end
	end
end

local function Intro()
		EVENT_MANAGER:UnregisterForEvent("SteadyPurse", EVENT_PLAYER_ACTIVATED)
		d("|c3A92FFSteady|cFFD700Purse|cFFFFFF version |c3A92FF" .. SPversion .. "|cFFFFFF loaded.")
		if (sv.AutoBank == true) then
			d("|c3A92FFSteady|cFFD700Purse|cFFFFFF is |c3A92FFenabled |cFFFFFFfor this character.")
		else
			d("|c3A92FFSteady|cFFD700Purse|cFFFFFF is |cDD1111disabled |cFFFFFFfor this character.")
		end
		
end

EVENT_MANAGER:RegisterForEvent("SteadyPurse", EVENT_ADD_ON_LOADED, Initialize)
EVENT_MANAGER:RegisterForEvent("SteadyPurse", EVENT_PLAYER_ACTIVATED, Intro)